@@ -170,6 +170,8 @@ evdev_process_events(int fd, uint32_t events)
 	      break;
 
 	    kbd_backlight_step(STEP_DOWN);
+	    if (kbd_bck_info.level == KBD_BACKLIGHT_OFF)
+	      kbd_backlight_inhibit_set(KBD_INHIBIT_USER);
 	    break;
 
 	  case KEY_KBDILLUMUP:
@@ -178,6 +180,7 @@ evdev_process_events(int fd, uint32_t events)
 	    if (!has_kbd_backlight())
 	      break;
 
+	    kbd_backlight_inhibit_clear(KBD_INHIBIT_USER);
 	    kbd_backlight_step(STEP_UP);
 	    break;
 
@@ -343,7 +346,9 @@ evdev_is_adb(unsigned short *id)
   if (id[ID_VENDOR] != 0x0001)
     return 0;
 
-  if (product == ADB_PRODUCT_ID_KEYBOARD)
+  if ((product == ADB_PRODUCT_ID_KEYBOARD_ANSI)
+      || (product == ADB_PRODUCT_ID_KEYBOARD_ISO)
+      || (product == ADB_PRODUCT_ID_KEYBOARD_JIS))
     {
       logdebug(" -> ADB keyboard\n");
 
